Reference
=========


.. _primitives-label:

Primitives
----------

2D core primitives
~~~~~~~~~~~~~~~~~~

.. autoclass:: volmdlr.Vector2D
  :members:

.. autoclass:: volmdlr.Point2D
  :members:

.. autoclass:: volmdlr.Basis2D
  :members:

.. autoclass:: volmdlr.Frame2D
  :members:


.. autoclass:: volmdlr.Line2D
  :members:

.. autoclass:: volmdlr.LineSegment2D
  :members:

.. autoclass:: volmdlr.Polygon2D
  :members:

.. autoclass:: volmdlr.Arc2D
  :members:


2D advanced primitives
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: volmdlr.primitives2D.RoundedLineSegments2D
  :members:


3D core Primitives
~~~~~~~~~~~~~~~~~~

.. autoclass:: volmdlr.Vector3D
  :members:

.. autoclass:: volmdlr.Point3D
  :members:

.. autoclass:: volmdlr.Basis3D
  :members:

.. autoclass:: volmdlr.Frame3D
  :members:


.. autoclass:: volmdlr.Line3D
  :members:

.. autoclass:: volmdlr.LineSegment3D
  :members:

.. autoclass:: volmdlr.Arc3D
  :members:


3D advanced primitives
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: volmdlr.primitives3D.RoundedLineSegments3D
  :members:

.. autoclass:: volmdlr.primitives3D.Cylinder
  :members:

.. autoclass:: volmdlr.primitives3D.HollowCylinder
  :members:

.. autoclass:: volmdlr.primitives3D.ExtrudedProfile
  :members:

.. autoclass:: volmdlr.primitives3D.Sphere
  :members:

.. autoclass:: volmdlr.primitives3D.RevolvedProfile
  :members:

.. autoclass:: volmdlr.primitives3D.HelicalExtrudedProfile
  :members:

.. autoclass:: volmdlr.primitives3D.Sweep
  :members:

.. autoclass:: volmdlr.primitives3D.Cut
  :members:

.. autoclass:: volmdlr.primitives3D.Fuse
  :members:
